Module: Astrolabe::Sexp
- Defined in:
- lib/astrolabe/sexp.rb
Overview
This module provides a shorthand method to create a Node like AST::Sexp.
Instance Method Summary collapse
-
#s(type, *children) ⇒ Object
Creates a Node with type
typeand childrenchildren.
Instance Method Details
#s(type, *children) ⇒ Object
Creates a Node with type type and children children.
11 12 13 |
# File 'lib/astrolabe/sexp.rb', line 11 def s(type, *children) Node.new(type, children) end |